@@ -1,24 +1,17 @@
+# ja/add_bookmark.rb $Revision 1.3 $
+#
 # Japanese resource of add_bookmark.rb
 #
 
 @add_bookmark_label = '֥åޡɲ'
 @add_bookmark_desc = 'ڡߤ󥯤åƤ'
 
-@used_icon_label = 'λ'
-@icon_label = 'Ѥ'
-
 @caption_hatena = 'ϤƤʥ֥åޡɲ'
 @caption_del = 'del.icio.usɲ'
 @caption_mm = 'MM/Memoɲ'
-@caption_webshots = 'webshotsɲ'
-@caption_fc2 = 'fc2 ֥åޡɲ'
-@caption_live = 'LiVEMARKɲ'
 
 @bookmark_label = [
    'ϤƤʥ֥åޡ',
    'del.icio.us',
    'MM/Memo',
-   'webshots',
-   'fc2 ֥åޡ',
-   'LiVEMARK'
 ]
