@@ -1,5 +1,5 @@
 #
-# Japanese resource of amazon plugin $Revision: 1.3.2.5 $
+# Japanese resource of amazon plugin $Revision: 1.3.2.8 $
 #
 # Copyright (C) 2002 HAL99 <hal99@mtj.biglobe.ne.jp>
 # You can redistribute it and/or modify it under GPL2.
@@ -44,6 +44,11 @@
 #                                (0:  1:  2:)
 #   @options['amazon.hidename']: class="amazon"ΤȤ˾̾ɽ
 #                                ʤ硢trueꤷޤ
+#   @options['amazon.default_image_base']: ǥեȤΥ᡼Ǽ
+#                                 URLꤷޤ̵ˤtDiary.org
+#                                 ˤΤȤޤˤ
+#                                 ץ饰amazonǥ쥯ȥˤPNG
+#                                 ե򻲹ͤˤƲ
 #   @options['amazon.nodefault']: ǥեȤΥ᡼ɽʤ
 #                                 trueꤷޤ
 #
@@ -53,10 +58,12 @@
 #
 
 @amazon_url = 'http://www.amazon.co.jp/exec/obidos/ASIN'
-@amazon_item_name = /^Amazon.co.jp[:] *(.*): .*$/
+@amazon_ecs_url = 'http://webservices.amazon.co.jp/onca/xml'
+@amazon_item_name = /^Amazon.co.jp (.*)<.*$/
 @amazon_item_image = %r|(<img src="(http://images-jp\.amazon\.com/images/P/(.*MZZZZZZZ_?.jpg))".*?>)|i
-@amazon_label_conf ='Amazonץ饰'
+@amazon_label_conf ='Amazon'
 @amazon_label_aid = 'AmazonIDλ'
+@amazon_label_aid_desc = 'ꤷʤˤϡtDiaryԤνͭIDꤵ줿ȤˤʤޤΤǤդ'
 @amazon_label_imgsize = 'ɽ륤᡼Υ'
 @amazon_label_large = '礭'
 @amazon_label_regular = ''
@@ -69,5 +76,15 @@
 @amazon_label_usedefault = 'ǥեȤΥ᡼Ȥ'
 @amazon_label_clearcache = 'åκ'
 @amazon_label_clearcache_desc = '᡼ϢΥå(Amazonɽ̷⤬˻Ʋ)'
-@amazon_label_over18 = 'Ⱦʤν'
-@amazon_label_over18_desc = 'ȾʤνƤ롣Ǥ˼ѤߤνƤ̵櫓ǤϤʤΤǡɬפ˱ƥåƲ'
+
+begin
+	require 'uconv'
+	@amazon_encoder = Proc::new {|s| Uconv.u8toeuc( s ) }
+rescue LoadError
+	begin
+		require 'nkf'
+		@amazon_encoder = Proc::new {|s| NKF::nkf( '-We', s ) }
+	rescue LoadError
+		@amazon_encoder = Proc::new {|s| s }
+	end
+end
