@@ -1,5 +1,5 @@
 =begin
-= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.11.2.1 2005/07/20 08:25:02 tadatadashi Exp $-))
+= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.11.2.2 2006/03/18 10:29:22 tadatadashi Exp $-))
 ܸ꥽
 
 == 
@@ -575,4 +575,6 @@ DispReferrer2_Engines = {
 	'102' => [[%r{\Ahttp://66\.102\.([0-9]|1[0-5])\.}i, '"Google"', ['as_q', 'q'], DispReferrer2_Google_cache]],
 	# other google candidates:
 	'216' => [[%r{\Ahttp://(\d+\.){3}\d+/search}i, '"Google?"', ['as_q', 'q'], DispReferrer2_Google_cache]],		# cache servers of google?
+	# NetRange:   72.14.192.0 - 72.14.255.255
+	'14' => [[%r{\Ahttp://72\.14\.(19[2-9]|2\d\d)\.}i, '"Google"', ['as_q', 'q'], DispReferrer2_Google_cache]],
 }
