@@ -1,4 +1,4 @@
-# makelirs.rb $Revision: 1.13 $
+# makelirs.rb $Revision: 1.14.2.2 $
 #
 # LIRSեޥåȤΥեǤФ
 #
@@ -11,6 +11,7 @@
 #   ⡢WebФ񤭹븢¤ɬפǤ
 #
 # Copyright (C) 2002 by Kazuhiro NISHIYAMA
+# You can redistribute it and/or modify it under GPL2.
 #
 
 add_header_proc do
@@ -51,7 +52,12 @@ add_update_proc do
 	file = @options['makelirs.file'] || 'antenna.lirs'
 
 	# create_lirs
-	t = TDiaryLatest::new( @cgi, "latest.rhtml", @conf )
+	cgi = @cgi.clone
+	conf = @conf.clone
+	def cgi.mobile_agent?; false; end
+	def conf.mobile_agent?; false; end
+
+	t = TDiaryLatest::new( cgi, "latest.rhtml", conf )
 	body = t.eval_rhtml
 	# escape comma
 	e = proc{|str| str.gsub(/[,\\]/) { "\\#{$&}" } }
@@ -59,7 +65,11 @@ add_update_proc do
 	now = Time.now
 	utc_offset = now.utc_offset
 
-	lirs = "LIRS,#{t.last_modified.tv_sec},#{Time.now.tv_sec},#{utc_offset},#{body.size},#{e[@conf.base_url]},#{e[@html_title]},#{e[@author_name]},,\n"
+	uri = @conf.index.dup
+	uri[0, 0] = @conf.base_url if %r|^https?://|i !~ @conf.index
+	uri.gsub!( %r|/\./|, '/' )
+
+	lirs = "LIRS,#{t.last_modified.tv_sec},#{Time.now.tv_sec},#{utc_offset},#{body.size},#{uri},#{e[@html_title]},#{e[@author_name]},,\n"
 	File::open( file, 'w' ) do |o|
 		o.puts lirs
 	end
