@@ -1,5 +1,5 @@
 =begin
-= A little bit more powerful display of referrers((-$Id: disp_referrer.rb,v 1.1 2004/06/15 15:19:21 tadatadashi Exp $-))
+= A little bit more powerful display of referrers((-$Id: disp_referrer.rb,v 1.1.2.1 2005/07/20 08:25:02 tadatadashi Exp $-))
 English resource
 
 == Copyright notice
@@ -85,7 +85,7 @@ Disp_referrer2_cache_info = <<'_END'
 _END
 Disp_referrer2_update_info = <<'_END'
 <p>
-	Please <a href="%2$s">update the cache</a>
+	Please update the cache
 	after editing the <a href="%1$s">today's link</a> lists.
 </p>
 _END
