@@ -1,6 +1,9 @@
 #
 # ja/00default.rb: Japanese resources of 00default.rb.
 #
+# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# You can redistribute it and/or modify it under GPL2.
+#
 
 #
 # header
@@ -186,7 +189,7 @@ add_conf_proc( 'display', 'ɽ' ) do
 	<h3 class="subtitle">ǿɽκ</h3>
 	#{"<p>ǿɽȤˡΥڡ˲ʬɽ뤫ꤷޤ</p>" unless @conf.mobile_agent?}
 	<p><input name="latest_limit" value="#{ @conf.latest_limit }" size="2">ʬ</p>
-	<h3 class="subtitle">Ĺǯɽ</h4>
+	<h3 class="subtitle">Ĺǯɽ</h3>
 	#{"<p>Ĺǯɽ뤿Υ󥯤ɽ뤫ɤꤷޤ</p>" unless @conf.mobile_agent?}
 	<p><select name="show_nyear">
 		<option value="true"#{if @conf.show_nyear then " selected" end}>ɽ</option>
@@ -263,3 +266,86 @@ add_conf_proc( 'referer', '󥯸' ) do
 	<p><textarea name="referer_table" cols="70" rows="10">#{@conf.referer_table2.collect{|a|a.join( " " )}.join( "\n" )}</textarea></p>
 	HTML
 end
+
+add_conf_proc( 'csrf_protection', 'CSRF(ü)к' ) do
+	err = saveconf_csrf_protection
+	errstr = ''
+	case err
+	when :param
+		errstr = '<p class="message">Ȥ߹碌ǤѹޤǤ</p>'
+	when :key
+		errstr = '<p class="message">ǤѹޤǤ</p>'
+	end
+	csrf_protection_method = @conf.options['csrf_protection_method'] || 1
+	csrf_protection_key = @conf.options['csrf_protection_key'] || ''
+	<<-HTML
+	#{errstr}
+	<p>ȡꥯȥե(CSRF)кˡꤷޤ</p>
+	<p>CSRFϡդΤʹ֤Webڡ櫤ųݤޤ
+	櫤ųݤڡ򤢤ʤȡʤΥ֥饦
+	tDiary˵ν񤭹׵ФƤޤޤʤΥ֥饦
+	׵ФƤޤᡢŹ沽ѥݸǤкˤʤޤ
+	tDiaryǤϡμιФơRefereråפȡCSRFפȤ
+	2ɱҼʤѰդƤޤ</p>
+	<div class="section">
+	<h3 class="subtitle">Refereråˤɱ</h3>
+	<h4>Refererθ</h4>
+	<p>#{if [0,1,2,3].include?(csrf_protection_method) then
+            '<input type="checkbox" name="check_enabled2" value="true" checked disabled>
+            <input type="hidden" name="check_enabled" value="true">'
+          else
+            '<input type="checkbox" name="check_enabled" value="true">'
+        end}(ɸ)</input>
+	</p>
+	#{"<p>ʤΥ֥饦ФReferer(󥯸)򸡺ޤ
+	񤭹׵᤬ڡФ줿Ȥǧ뤳Ȥǡ
+	ڡ׵ɤޤʥڡ׵򸡽Ф硢
+	ꥯȤݤޤ
+	̤Ǥϡ̵ˤ뤳ȤϽޤ</p>
+	" unless @conf.mobile_agent?}
+	<h4>RefererФʤ֥饦</h4>
+	<p><input type="radio" name="check_referer" value="true" #{if [1,3].include?(csrf_protection_method) then " checked" end}>(ɸ)</input>
+	<input type="radio" name="check_referer" value="false" #{if [0,2].include?(csrf_protection_method) then " checked" end}>ʤ</input>
+	</p>
+	#{"<p>֥饦RefererƤʤäưꤷޤ</p>
+	<p>ɸǤϡRefererФʤ硢ʥꥯȤ
+	Ƚ̤Ǥʤᡢ񤭹ߡѹݤޤ
+	ʤΥ֥饦RefererФʤξ硢
+	꤬֤פˤʤäƤȡν񤭹׵ݤƤޤޤ
+	֥饦ѹRefererФ褦ˤƤ
+	ɤƤRefererФ˽ʤ硢֤ʤפˤƤ
+	ξ硢RefererФʤäˤ⡢
+	񤭹ߡѹ褦ˤʤޤ
+	CSRFˤ빶ȶ̤ǤʤʤޤΤǡɬΡCSRFɻߥפ
+	ʻѤƲ</p>
+	</div>
+	" unless @conf.mobile_agent?}
+	<div class="section">
+	<h3 class="subtitle">CSRFɻߥˤɱ</h3>
+	<h4>CSRFɻߥθ</h4>
+	<p><input type="radio" name="check_key" value="true" #{if [2,3].include?(csrf_protection_method) then " checked" end}></input>
+	<input type="radio" name="check_key" value="false" #{if [0,1].include?(csrf_protection_method) then " checked" end}>ʤ(ɸ)</input>
+	</p>
+	#{"<p>񤭹ߥե˵񤭹ɻߤΤΥꤷCSRFɤޤ
+	ڡ̩ΥΤʤ¤ꡢ
+	ν񤭹׵뤳ȤǤʤʤޤ
+	θ֤פꤹ硢θꤷƲ
+	ξ֤ʤפˤ뤳ȤϤǤޤ</p>
+	<p>֤פˤ硢εбƤʤ
+	ץ饰ưʤʤ뤳Ȥޤ</p>
+	" unless @conf.mobile_agent?}
+	<h4>CSRF ɻߥ</h4>
+	<p><input type="text" name="key" value="#{CGI::escapeHTML csrf_protection_key}" size="30"></p>
+	#{"<p>ɻߥꤷޤ¬ˤŬʸꤷƲ
+	θ˱̤ȡCSRFǽޤ
+	¾ΥѥɤȶѤϤƤϤޤ󡣤ʤꤷʸ򤢤ʤФƤɬפϤޤ</p>" unless @conf.mobile_agent?}
+	#{"<p class=\"message\">: 
+	ʤΥ֥饦ϸRefererФƤʤ褦Ǥ
+	<a href=\"#{@conf.update}?conf=csrf_protection\">Υ󥯤⤦
+	Υڡ򳫤ƤߤƲ</a>
+	Ǥ⤳ΥåФǤϡѤ硢
+	ŪRefererФˤ뤫
+	ľtdiary.confԽƲ</p>
+	</div>" if [1,3].include?(csrf_protection_method) && ! @cgi.referer && !@cgi.valid?('referer_exists')}
+	HTML
+end
